@@ -20,8 +20,10 @@
 from __future__ import print_function
 import os
 import sys
+import time
 import socket
 import platform
+import traceback
 
 from bioservices.settings import BioServicesConfig
 
@@ -48,7 +50,7 @@ from easydev import Logging
 from easydev import DevTools
 
 
-__all__ = ["Service", "WSDLService", 
+__all__ = ["Service", "WSDLService",
            "BioServicesError", "REST"]
 
 
@@ -80,7 +82,7 @@ class Service(object):
         503: 'Service not available. The server is being updated, try again later'
         }
 
-    def __init__(self, name, url=None, verbose=True, requests_per_sec=3):
+    def __init__(self, name, url=None, verbose=True, requests_per_sec=10):
         """.. rubric:: Constructor
 
         :param str name: a name for this service
@@ -90,7 +92,7 @@ class Service(object):
         :param requests_per_sec: maximum number of requests per seconds
             are restricted to 3. You can change that value. If you reach the
             limit, an error is raise. The reason for this limitation is
-            that some services (e.g.., NCBI) may black list you IP. 
+            that some services (e.g.., NCBI) may black list you IP.
             If you need or can do more (e.g., ChEMBL does not seem to have
             restrictions), change the value. You can also have several instance
             but again, if you send too many requests at the same, your future
@@ -115,7 +117,6 @@ class Service(object):
         """
         super(Service, self).__init__()
         self.requests_per_sec = requests_per_sec
-
         self.name = name
         self.logging = Logging("bioservices:%s" % self.name, verbose)
 
@@ -135,6 +136,25 @@ class Service(object):
         self.devtools = DevTools()
         self.settings = BioServicesConfig()
 
+        self._last_call = 0
+
+    def _calls(self):
+        time_lapse = 1. / self.requests_per_sec
+        current_time = time.time()
+        dt = current_time - self._last_call
+        
+        if self._last_call == 0:
+            self._last_call = current_time
+            return
+        else:
+            self._last_call = current_time
+            if dt > time_lapse:
+                return
+            else:
+                time.sleep(time_lapse - dt)
+        
+
+
     def _get_caching(self):
         return self.settings.params['cache.on'][0]
     def _set_caching(self, caching):
@@ -163,7 +183,7 @@ class Service(object):
             raise TypeError("value must be a boolean value (True/False)")
         self._easyXMLConversion = value
     easyXMLConversion = property(_get_easyXMLConversion,
-            _set_easyXMLConversion, 
+            _set_easyXMLConversion,
             doc="""If True, xml output from a request are converted to easyXML object (Default behaviour).""")
 
     def easyXML(self, res):
@@ -188,7 +208,6 @@ class Service(object):
         from bioservices import xmltools
         return xmltools.easyXML(res)
 
-
     def __str__(self):
         txt = "This is an instance of %s service" % self.name
         return txt
@@ -282,7 +301,7 @@ class WSDLService(Service):
     def _get_methods(self):
         return [x.name for x in
                 self.suds.wsdl.services[0].ports[0].methods.values()]
-    wsdl_methods = property(_get_methods, 
+    wsdl_methods = property(_get_methods,
             doc="returns methods available in the WSDL service")
 
     def wsdl_create_factory(self, name, **kargs):
@@ -316,8 +335,9 @@ class WSDLService(Service):
 
 class RESTbase(Service):
     _service = "REST"
-    def __init__(self, name, url=None, verbose=True):
-        super(RESTbase, self).__init__(name, url, verbose=verbose)
+    def __init__(self, name, url=None, verbose=True, requests_per_sec=3):
+        super(RESTbase, self).__init__(name, url, verbose=verbose,
+            requests_per_sec=requests_per_sec)
         self.logging.info("Initialising %s service (REST)" % self.name)
         self.last_response = None
 
@@ -381,12 +401,29 @@ class REST(RESTbase):
 
     There is no need for authentication if the web services available
     in bioservices except for a few exception. In such case, the username and
-    password are to be provided with the method call. However, 
+    password are to be provided with the method call. However,
     in the future if a services requires authentication, one can set the
     attribute :attr:`authentication` to a tuple::
 
         s = REST()
         s.authentication = ('user', 'pass')
+
+
+    Note about headers and content type. The Accept header is 
+    used by HTTP clients to tell the server what content types 
+    they will accept. The server will then send back a
+    response, which will include a Content-Type header telling 
+    the client what the content type of the returned content 
+    actually is. When using the :meth:`get__headers`, you can see
+    the User-Agent, the Accept and Content-Type keys. So, here the 
+    HTTP requests also contain Content-Type headers. In POST or PUT requests
+    the client is actually sendingdata to the server as part of the
+    request, and the Content-Type header tells the server what the data actually is
+    For a POST request resulting from an HTML form submission, the
+    Content-Type of the request should be one of the standard form content
+    types: application/x-www-form-urlencoded (default, older, simpler) or 
+    multipart/form-data (newer, adds support for file uploads)
+
     """
     content_types = {
         'bed': 'text/x-bed',
@@ -406,8 +443,10 @@ class REST(RESTbase):
     }
     #special_characters = ['/', '#', '+']
 
-    def __init__(self, name, url=None, verbose=True, cache=False):
-        super(REST, self).__init__(name, url, verbose=verbose)
+    def __init__(self, name, url=None, verbose=True, cache=False,
+        requests_per_sec=3):
+        super(REST, self).__init__(name, url, verbose=verbose,
+            requests_per_sec=requests_per_sec)
         bspath = self.settings.user_config_dir
         self.CACHE_NAME = bspath + os.sep + self.name + "_bioservices_db"
 
@@ -435,6 +474,20 @@ class REST(RESTbase):
         from requests_cache import clear
         clear()
 
+    def _build_url(self, query):
+        url = None
+
+        if query is None:
+            url = self.url
+        else:
+            if query.startswith("http"):
+                # assume we do want to use self.url
+                url = query
+            else:
+                url = '%s/%s' % (self.url, query)
+
+        return url
+
     def _get_session(self):
         if self._session is None:
             if self.CACHING is True:
@@ -551,21 +604,22 @@ class REST(RESTbase):
         # OTHERWISE
         self.logging.debug("Running http_get (single call mode)")
         #return self.get_one(**{'frmt': frmt, 'query': query, 'params':params})
-        return self.get_one(query, frmt, params=params, **kargs)
+
+        headers = kargs.get("headers", self.get_headers())
+        kargs.update({"headers": headers})
+        return self.get_one(query, frmt, params=params,  **kargs)
 
     def get_one(self, query=None, frmt='json', params={}, **kargs):
         """
 
         if query starts with http:// do not use self.url
         """
-        if query is None:
-            url = self.url
-        else:
-            if query.startswith("http"):
-                # assume we do want to use self.url
-                url = query
-            else:
-                url = '%s/%s' % (self.url, query)
+        self._calls()
+        url = self._build_url(query)
+
+        if url.count('//') >1:
+            self.logging.warning("URL of the services contains a double //." +
+                "Check your URL and remove trailing /")
         self.logging.debug(url)
         try:
             kargs['params'] = params
@@ -588,8 +642,8 @@ class REST(RESTbase):
             return res
         except Exception as err:
             self.logging.critical(err)
-            self.logging.critical("""Issue. Maybe your current timeout is {0} is not sufficient. 
-Consider increasing it with settings.TIMEOUT attribute""".format(self.settings.TIMEOUT))
+            self.logging.critical("""Query unsuccesful. Maybe too slow response.
+    Consider increasing it with settings.TIMEOUT attribute {}""".format(self.settings.TIMEOUT))
 
     def http_post(self, query, params=None, data=None,
                     frmt='xml', headers=None, files=None, **kargs):
@@ -613,6 +667,7 @@ Consider increasing it with settings.TIMEOUT attribute""".format(self.settings.T
         return self.post_one(**kargs)
 
     def post_one(self, query=None, frmt='json', **kargs):
+        self._calls()
         self.logging.debug("BioServices:: Entering post_one function")
         if query is None:
             url = self.url
@@ -629,15 +684,16 @@ Consider increasing it with settings.TIMEOUT attribute""".format(self.settings.T
                 self.logging.debug("BioServices:: Could not decode the response")
                 return res
         except Exception as err:
-            print(err)
+            traceback.print_exc()
             return None
 
     def getUserAgent(self):
         self.logging.info('getUserAgent: Begin')
         urllib_agent = 'Python-requests/%s' % requests.__version__
         #clientRevision = ''
-        clientVersion = ''
-        user_agent = 'EBI-Sample-Client/%s (%s; Python %s; %s) %s' % (
+        from bioservices import version
+        clientVersion = version
+        user_agent = 'BioServices/%s (bioservices.%s; Python %s; %s) %s' % (
             clientVersion, os.path.basename(__file__),
             platform.python_version(), platform.system(),
             urllib_agent
@@ -648,7 +704,7 @@ Consider increasing it with settings.TIMEOUT attribute""".format(self.settings.T
 
     def get_headers(self, content='default'):
         """
-        :param str content: ste to default that is application/x-www-form-urlencoded
+        :param str content: set to default that is application/x-www-form-urlencoded
             so that it has the same behaviour as urllib2 (Sept 2014)
 
         """
@@ -670,9 +726,12 @@ Consider increasing it with settings.TIMEOUT attribute""".format(self.settings.T
         kargs.update({'query': query})
         kargs.update({'params': params})
         kargs.update({'frmt': frmt})
+
+
         return self.delete_one(**kargs)
 
     def delete_one(self, query, frmt='json', **kargs):
+        self._calls()
         self.logging.debug("BioServices:: Entering delete_one function")
         if query is None:
             url = self.url
