@@ -18,10 +18,6 @@ def test_annotations_from_goid(quickgo):
     df = quickgo.Annotation_from_goid(goId="GO:0003824,GO:0003677", taxonId="9606" )
     assert len(df)
 
-def test_goterms(quickgo):
-    res = quickgo.goterms(max_number_of_pages=5)
-
-
 def test_Term(quickgo):
-    res = quickgo.Terms("GO:0003824,GO:0003677")
+    res = quickgo.goterms("GO:0003824,GO:0003677")
     assert len(res) == 2
